/*
*******************************************************************************
**
**  This device driver was created by Applilet for the 78K0S/KB1+, 78K0S/KA1+,
**  78K0S/KY1+,78K0S/KU1+ 8-Bit Single-Chip Microcontrollers.
**
**  Copyright(C) NEC Electronics Corporation 2002-2006
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	main.c
**  Abstract :	This file implements main function.
**  APIlib :	NEC78K0SKX1+.lib V1.70 [7 Dec. 2006]
**
**  Device :	uPD78F9222
**
**  Compiler :	NEC/CC78K0
**
*******************************************************************************
*/
/*
*******************************************************************************
**  Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "system.h"
#include "ad.h"
#include "int.h"
#include "port.h"
#include "watchdogtimer.h"
#include "lvi.h"
/*
*******************************************************************************
**  MacroDefine
*******************************************************************************
*/
/*
**---------------------------------------------------------------------------
**
**  Abstract:
**	This function implements main function.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**---------------------------------------------------------------------------
*/

unsigned short	ad_data;		/* ADł̎擾l			*/

int	ad_x;
int	ad_y;
int	ad_z;
int	ref_x;
int	ref_y;
int	ref_z;


void	wait_time(unsigned int time)
{
	while(time!=0){
		time--;
	}
}
/*----------  LCD MODULE ----------*/
void	lcd_db(unsigned char data)
{
	P4.0=data&0x01;
	P4.1=(data&0x02)>>1;
	P4.2=(data&0x04)>>2;
	P4.3=(data&0x08)>>3;
}
void	lcd_wait(void)
{
	wait_time(5000);
}
void	lcd_c_set(void)
{
	P3.1=0;
	P3.0=1;
	wait_time(10);
	P3.0=0;
}
void	lcd_d_set(void)
{
	P3.1=1;
	P3.0=1;
	wait_time(10);
	P3.0=0;
}
void	lcd_cmd(unsigned char data)
{
	lcd_db((data&0xf0)>>4);
	lcd_c_set();
	lcd_db(data&0x0f);
	lcd_c_set();
	wait_time(300);
}
void	lcd_data(unsigned char data)
{
	lcd_db((data&0xf0)>>4);
	lcd_d_set();
	lcd_db(data&0x0f);
	lcd_d_set();
	wait_time(300);
}
void	lcd_init(void)
{
	lcd_wait();
	lcd_db(3);
	lcd_c_set();
	lcd_wait();
	lcd_db(3);
	lcd_c_set();
	lcd_wait();
	lcd_db(3);
	lcd_c_set();
	lcd_wait();
	lcd_db(2);
	lcd_c_set();
	lcd_wait();
	
	lcd_cmd(0x28);
	lcd_cmd(0x08);
	lcd_cmd(0x0c);
	lcd_cmd(0x06);
}
void	lcd_clear(void)
{
	lcd_cmd(0x01);
}
void	lcd_xy(unsigned char x,unsigned char y)
{
unsigned char data;

	data=0x80;
	switch (y){
		case 0:data=0x80;break;
		case 1:data=0xc0;break;
		case 2:data=0x90;break;
		case 3:data=0xd0;break;
	}
	data=data+x;
	lcd_cmd(data);
}
void	lcd_print(char *data)
{
	while (*data!=0){
		lcd_data(*data++);
	}
}
void	lcd_su(unsigned char data)
{
	switch (data){
		case 0:lcd_print("0");break;
		case 1:lcd_print("1");break;
		case 2:lcd_print("2");break;
		case 3:lcd_print("3");break;
		case 4:lcd_print("4");break;
		case 5:lcd_print("5");break;
		case 6:lcd_print("6");break;
		case 7:lcd_print("7");break;
		case 8:lcd_print("8");break;
		case 9:lcd_print("9");break;
		case 10:lcd_print("A");break;
		case 11:lcd_print("B");break;
		case 12:lcd_print("C");break;
		case 13:lcd_print("D");break;
		case 14:lcd_print("E");break;
		case 15:lcd_print("F");break;
	}
}
void	lcd_sub4(unsigned int no)
{
unsigned char n0,n1,n2,n3;
unsigned int count;
unsigned char f;

	count=no;
	n0=(unsigned char)(count%10);count=(count-n0)/10;
	n1=(unsigned char)(count%10);count=(count-n1)/10;
	n2=(unsigned char)(count%10);count=(count-n2)/10;
	n3=(unsigned char)(count%10);

	if(n3==0){lcd_print(" ");f=0;}else{lcd_su(n3);f=1;}
	if((n2==0)&&(f==0)){lcd_print(" ");}else{lcd_su(n2);f=1;}
	if((n1==0)&&(f==0)){lcd_print(" ");}else{lcd_su(n1);f=1;}
	lcd_su(n0);
}
void	lcd_disp(void)
{
int	x,y,z;
unsigned char	fx,fy,fz;

	if(ref_x>ad_x){x=ref_x-ad_x;fx=1;}
	else{x=ad_x-ref_x;fx=0;}
	
	if(ref_y>ad_y){y=ref_y-ad_y;fy=1;}
	else{y=ad_y-ref_y;fy=0;}

	if(ref_z>ad_z){z=ref_z-ad_z;fz=1;}
	else{z=ad_z-ref_z;fz=0;}

	lcd_xy(0,1);
	lcd_sub4(x);lcd_xy(0,1);
	if(fx==1){lcd_print("-");}
	else{lcd_print(" ");}
	lcd_xy(5,1);
	lcd_sub4(y);lcd_xy(5,1);
	if(fy==1){lcd_print("-");}
	else{lcd_print(" ");}
	lcd_xy(10,1);
	lcd_sub4(z);lcd_xy(10,1);
	if(fz==1){lcd_print("-");}
	else{lcd_print(" ");}
}

void main( void )
{
unsigned int	sub;
unsigned char	sw1_key;
unsigned char	sw1_rep;


	sub=0;
	ref_x=512;
	ref_y=512;
	ref_z=512;

	lcd_init();
	lcd_clear();
	lcd_xy(0,0);
	lcd_print("  x    y    z");

	/* TODO. add user code */
	while(1){
	
	/* key scan 1 */
		if (P2.3==0){
				sw1_key=0;
		}
		else{
			sw1_key=1;
			sw1_rep=0;
		}
		/*------------------*/

	
		AD_Start(ADChannel0);
		AD_Read(&ad_data);
		ad_z=ad_data;
	
		AD_Start(ADChannel1);
		AD_Read(&ad_data);
		ad_y=ad_data;
	
		AD_Start(ADChannel2);
		AD_Read(&ad_data);
		ad_x=ad_data;

		if(sub==0){
			lcd_disp();
			sub=100;
		}
		else{
			sub--;
		}

	/* key scan 2 */
		if ((P2.3==0)&(sw1_key==0)){
			sw1_key=0;
		}
		else{
			sw1_key=1;
			sw1_rep=0;
		}
		/*------------------*/

	/* key action */
	
		if((sw1_key==0)&(sw1_rep==0)){
			sw1_rep=1;
			sub=0;
			ref_x=ad_x;
			ref_y=ad_y;

		}





	}
}

